summaryrefslogtreecommitdiffstats
path: root/lldb/tools/debugserver/source/JSON.h
diff options
context:
space:
mode:
authorZachary Turner <zturner@google.com>2016-08-29 19:45:59 +0000
committerZachary Turner <zturner@google.com>2016-08-29 19:45:59 +0000
commit44c35e80b165cbd193a39966b7ba434b676071c0 (patch)
tree760fb68de81aed88407eb82c7ec26c2ec14cd857 /lldb/tools/debugserver/source/JSON.h
parent47ca88ace26370365fbd2a5919be4af66fa7f4a6 (diff)
downloadbcm5719-llvm-44c35e80b165cbd193a39966b7ba434b676071c0.tar.gz
bcm5719-llvm-44c35e80b165cbd193a39966b7ba434b676071c0.zip
Copy StringExtractor to StdStringExtractor.
I have some improvements to make to StringExtractor that require using LLVM. debugserver can't take a dependency on LLVM but uses this file, so I'm forking it off into StdStringExtractor and StringExtractor, so that StringExtractor can take advantage of some performance improvements and readability improvements that LLVM can provide. llvm-svn: 279997
Diffstat (limited to 'lldb/tools/debugserver/source/JSON.h')
-rw-r--r--lldb/tools/debugserver/source/JSON.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lldb/tools/debugserver/source/JSON.h b/lldb/tools/debugserver/source/JSON.h
index d1723d87a38..e24f928bcf7 100644
--- a/lldb/tools/debugserver/source/JSON.h
+++ b/lldb/tools/debugserver/source/JSON.h
@@ -10,9 +10,9 @@
#ifndef utility_JSON_h_
#define utility_JSON_h_
// This cross-project usage is fine as StringExtractor.h is entirely
// self-contained.
-#include "lldb/Utility/StringExtractor.h"
+#include "lldb/Utility/StdStringExtractor.h"
// C includes
#include <inttypes.h>
@@ -338,7 +338,7 @@ public:
Vector m_elements;
};
-class JSONParser : public StringExtractor
+class JSONParser : public StdStringExtractor
{
public:
enum Token
@@ -10,9 +10,9 @@
#ifndef utility_JSON_h_
#define utility_JSON_h_
-// This cross-project usage is fine as StringExtractor.h is entirely
+// This cross-project usage is fine as StdStringExtractor.h is entirely
// self-contained.
OpenPOWER on IntegriCloud